@@ -43,8 +43,17 @@ my %filter_for = (
             return 0;
         },
     },
+    numberfield => {
+        from_db => sub { shift },
+        to_db   => sub {
+            my $val = shift;
+            return undef if !defined $val or $val eq '';
+            return $val;
+        },
+    },
 );
 
+# stringify a row of fields according to rules described in our POD
 sub _sfy {
     my $row = shift;
     return '' if !defined $row or !blessed $row;
@@ -56,6 +65,16 @@ sub _sfy {
     );
 }
 
+# find whether this DMBS supports ILIKE or just LIKE
+sub _likeop_for {
+    my $model = shift;
+    my $sqlt_type = $model->result_source->storage->sqlt_type;
+    my %ops = (
+        SQLite => '-like',
+    );
+    return $ops{$sqlt_type} || '-ilike';
+}
+
 # we're going to check that calls to this RPC operation are allowed
 sub acl : Private {
     my ($self, $c) = @_;
@@ -118,7 +137,7 @@ sub list : Chained('base') Args(0) {
     (my $dir  = $c->req->params->{'dir'}   || 'ASC') =~ s/\s//g;
 
     # sanity check the sort param
-    $sort = $info->{pk} if $sort !~ m/^\w+$/ or !exists $info->{cols}->{$sort};
+    $sort = $info->{pk} if $sort !~ m/^[\w ]+$/ or !exists $info->{cols}->{$sort};
 
     # set up pager, if needed
     my $search_opts = (($page =~ m/^\d+$/ and $limit =~ m/^\d+$/)
@@ -127,13 +146,24 @@ sub list : Chained('base') Args(0) {
     # find filter fields in UI form
     my $filter = {};
     foreach my $p (keys %{$c->req->params}) {
-        next unless $p =~ m/^search\.(\w+)/;
+        next unless $p =~ m/^search\.([\w ]+)/;
         my $col = $1;
         next unless exists $info->{cols}->{$col};
         next if $info->{cols}->{$col}->{is_fk} or $info->{cols}->{$col}->{is_rr};
 
+        # for numberish types the case insensitive functions may not work
+        if (exists $info->{cols}->{$col}->{extjs_xtype}
+            and $info->{cols}->{$col}->{extjs_xtype} eq 'numberfield') {
+            $filter->{$col} = $c->req->params->{"search.$col"};
+            next;
+        }
+
         # construct search clause if any of the filter fields were filled in UI
-        $filter->{$col} = { -like => '%'. $c->req->params->{"search.$col"} .'%' };
+        $filter->{"me.$col"} = {
+            # find whether this DMBS supports ILIKE or just LIKE
+            _likeop_for($c->model($lf->{model}))
+                => '%'. $c->req->params->{"search.$col"} .'%'
+        };
     }
 
     # sort col which can be passed to the db
@@ -142,38 +172,29 @@ sub list : Chained('base') Args(0) {
         $search_opts->{order_by} = \"me.$sort $dir";
     }
 
-    # aide memoire, according to pg manual:
-    # "It is also possible to use arbitrary expressions in the ORDER BY
-    # clause, including columns that do not appear in the SELECT result list."
-    if (my $list_returns = $c->stash->{site_conf}->{$db}->{$table}->{list_returns}) {
-        $search_opts->{columns} =
-            [(ref $list_returns eq 'HASH' ? keys %$list_returns : @$list_returns)];
-    }
-
-    # XXX FIXME mst, avert your eyes NOW!
-    my $convert =
-        $c->model($lf->{model})->result_source->storage->sql_maker->{convert};
-    $c->model($lf->{model})->result_source->storage->sql_maker->{convert}
-        = 'lower';
-    # okay, you can look again.
-
     my $rs = $c->model($lf->{model})->search($filter, $search_opts);
     my @columns = (exists $search_opts->{columns} ? @{$search_opts->{columns}}
                                                   : keys %{ $info->{cols} });
+
+    $c->model($lf->{model})->result_source->storage->debug(1)
+        if $c->debug;
+
     # make data structure for JSON output
     while (my $row = $rs->next) {
         my $data = {};
         foreach my $col (@columns) {
-            if (!defined $row->$col) {
-                $data->{$col} = '';
-                next;
-            }
-
             if ($info->{cols}->{$col}->{is_fk} or $info->{cols}->{$col}->{is_rr}) {
+                # here assume table names are sane perl identifiers
                 $data->{$col} = _sfy($row->$col);
             }
             else {
-                $data->{$col} = $row->$col;
+                if (!defined eval{$row->get_column($col)}) {
+                    $data->{$col} = '';
+                    next;
+                }
+                else {
+                    $data->{$col} = $row->get_column($col);
+                }
             }
 
             if (exists $info->{cols}->{$col}->{extjs_xtype}
@@ -207,11 +228,6 @@ sub list : Chained('base') Args(0) {
     $response->{total} =
         eval {$rs->pager->total_entries} || scalar @{$response->{rows}};
 
-    # XXX FIXME mst, avert your eyes NOW!
-    $c->model($lf->{model})->result_source->storage->sql_maker->{convert}
-        = $convert;
-    # okay, you can look again.
-
     # sneak in a 'top' row for applying the filters
     my %searchrow = ();
     foreach my $col (keys %{$info->{cols}}) {
@@ -234,6 +250,9 @@ sub list : Chained('base') Args(0) {
     }
     unshift @{$response->{rows}}, \%searchrow;
 
+    $c->model($lf->{model})->result_source->storage->debug(0)
+        if $c->debug;
+
     return $self;
 }
 
@@ -247,21 +266,30 @@ sub update : Chained('base') Args(0) {
     my $response = $c->stash->{json_data} = {};
 
     my $stack = _build_table_data($c, [], $lf->{model});
-    #use Data::Dumper;
-    #print STDERR Dumper $stack;
+    if ($c->debug) {
+        use Data::Dumper;
+        $c->log->debug(Dumper {table_stack => $stack});
+    }
 
     # stack is processed in one transaction, so either all rows are
     # updated, or none, and an error thrown.
 
-    #$c->model($lf->{model})->result_source->storage->debug(1);
+    $c->model($lf->{model})->result_source->storage->debug(1)
+        if $c->debug;
     my $success = eval {
         $c->model($lf->{model})->result_source->schema->txn_do(
             \&_process_row_stack, $c, $stack
         );
     };
-    #$c->model($lf->{model})->result_source->storage->debug(0);
+    if ($c->debug) {
+        use Data::Dumper;
+        $c->log->debug(Dumper {success => $success, exception => $@});
+    }
+    $response->{'success'} = (($success && !$@) ? 1 : 0);
+
+    $c->model($lf->{model})->result_source->storage->debug(0)
+        if $c->debug;
 
-    $response->{'success'} = ($success ? 'true' : 'false');
     return $self;
 }
 
@@ -406,10 +434,10 @@ sub delete : Chained('base') Args(0) {
 
     if (blessed $row) {
         $row->delete;
-        $response->{'success'} = 'true';
+        $response->{'success'} = 1;
     }
     else {
-        $response->{'success'} = 'false';
+        $response->{'success'} = 0;
     }
 
     return $self;
